@@ -15,7 +15,7 @@
  *
  *
  * IDENTIFICATION
- *		$Header: /cvsroot/pgsql-server/src/bin/pg_dump/pg_backup_archiver.c,v 1.62 2002/10/27 02:52:10 tgl Exp $
+ *		$Header: /cvsroot/pgsql/src/bin/pg_dump/pg_backup_archiver.c,v 1.62.2.6 2005/04/30 08:42:17 neilc Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -293,7 +293,8 @@ RestoreArchive(Archive *AHX, RestoreOptions *ropt)
 					 * Maybe we can't do BLOBS, so check if this node is
 					 * for BLOBS
 					 */
-					if ((strcmp(te->desc, "BLOBS") == 0) && !_canRestoreBlobs(AH))
+					if ((strcmp(te->desc, "BLOBS") == 0) &&
+						!_canRestoreBlobs(AH))
 					{
 						ahprintf(AH, "--\n-- SKIPPED \n--\n\n");
 
@@ -330,7 +331,7 @@ RestoreArchive(Archive *AHX, RestoreOptions *ropt)
 						 * mode with libpq.
 						 */
 						if (te->copyStmt && strlen(te->copyStmt) > 0)
-							ahprintf(AH, te->copyStmt);
+							ahprintf(AH, "%s", te->copyStmt);
 
 						(*AH->PrintTocDataPtr) (AH, te, ropt);
 
@@ -445,6 +446,10 @@ _disableTriggersIfNecessary(ArchiveHandle *AH, TocEntry *te, RestoreOptions *rop
 	if (!ropt->dataOnly || !ropt->disable_triggers)
 		return;
 
+	/* Don't do it for the BLOBS TocEntry, either */
+	if (te && strcmp(te->desc, "BLOBS") == 0)
+		return;
+
 	oldUser = strdup(AH->currUser);
 	oldSchema = strdup(AH->currSchema);
 
@@ -508,6 +513,10 @@ _enableTriggersIfNecessary(ArchiveHandle *AH, TocEntry *te, RestoreOptions *ropt
 	if (!ropt->dataOnly || !ropt->disable_triggers)
 		return;
 
+	/* Don't do it for the BLOBS TocEntry, either */
+	if (te && strcmp(te->desc, "BLOBS") == 0)
+		return;
+
 	oldUser = strdup(AH->currUser);
 	oldSchema = strdup(AH->currSchema);
 
@@ -1282,14 +1291,15 @@ static void
 _die_horribly(ArchiveHandle *AH, const char *modulename, const char *fmt, va_list ap)
 {
 	_write_msg(modulename, fmt, ap);
-	if (AH->public.verbose)
-		write_msg(NULL, "*** aborted because of error\n");
 
-	if (AH)
+	if (AH) {
+		if (AH->public.verbose)
+			write_msg(NULL, "*** aborted because of error\n");
 		if (AH->connection)
 			PQfinish(AH->connection);
-	if (AH->blobConnection)
-		PQfinish(AH->blobConnection);
+		if (AH->blobConnection)
+			PQfinish(AH->blobConnection);
+	}
 
 	exit(1);
 }
@@ -1440,7 +1450,7 @@ ReadOffset(ArchiveHandle *AH, off_t *o)
 	for (off = 0; off < AH->offSize; off++)
 	{
 		if (off < sizeof(off_t))
-			*o |= ((*AH->ReadBytePtr) (AH)) << (off * 8);
+			*o |= ((off_t) ((*AH->ReadBytePtr) (AH))) << (off * 8);
 		else
 		{
 			if ((*AH->ReadBytePtr) (AH) != 0)
@@ -1458,7 +1468,7 @@ WriteInt(ArchiveHandle *AH, int i)
 
 	/*
 	 * This is a bit yucky, but I don't want to make the binary format
-	 * very dependant on representation, and not knowing much about it, I
+	 * very dependent on representation, and not knowing much about it, I
 	 * write out a sign byte. If you change this, don't forget to change
 	 * the file version #, and modify readInt to read the new format AS
 	 * WELL AS the old formats.
@@ -1905,7 +1915,7 @@ ReadToc(ArchiveHandle *AH)
 			depIdx = 0;
 			do
 			{
-				if (depIdx > depSize)
+				if (depIdx >= depSize)
 				{
 					depSize *= 2;
 					deps = realloc(deps, sizeof(char *) * depSize);
@@ -1921,7 +1931,10 @@ ReadToc(ArchiveHandle *AH)
 			if (depIdx > 1)		/* We have a non-null entry */
 				te->depOid = realloc(deps, sizeof(char *) * depIdx);	/* trim it */
 			else
+			{
+				free(deps);
 				te->depOid = NULL;		/* no deps */
+			}
 		}
 		else
 			te->depOid = NULL;
@@ -2109,7 +2122,7 @@ _reconnectAsUser(ArchiveHandle *AH, const char *dbname, const char *user)
 		appendPQExpBuffer(qry, " %s\n\n",
 						  fmtId(user));
 
-		ahprintf(AH, qry->data);
+		ahprintf(AH, "%s", qry->data);
 
 		destroyPQExpBuffer(qry);
 
